package
Version:
v0.0.0-...-c62af90
Opens a new window with list of versions in this module.
Published: Jun 27, 2020
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func NewTimer(soundChan chan<- byte) *timer
type Keyboard interface {
WaitForKeyPressed() (key byte)
IsKeyPressed(key byte) bool
KeyPressed(key byte)
Clear()
}
type Screen interface {
Draw(frameBuffer []byte)
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.